/**
 * @license
 * Copyright (c) 2015 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */
/**
 * Maintains bidirectional indexes of the dependency graph, for quick querying.
 */
export declare class DependencyGraph {
    private _dependencies;
    private _dependants;
    constructor(from?: DependencyGraph);
    /**
     * Add dependencies of the given path.
     *
     * @param path The path (i.e. url) of a document.
     * @param newDependencies The paths of that document's direct dependencies.
     */
    addDependenciesOf(path: string, newDependencies: Iterable<string>): void;
    /**
     * Returns a fork of this graph without the documents at the given paths.
     */
    invalidatePaths(paths: string[]): DependencyGraph;
    /**
     * Returns the set of transitive dependencies on the given path.
     *
     * So if A depends on B which depends on C, then getAllDependentsOf(C) will
     * be Set([A,B]), and getAllDependantsOf(B) will be Set([A]).
     */
    getAllDependantsOf(path: string): Set<string>;
    private _getAllDependantsOf(path, visited, result);
}
